/* TEMPLATE D'UTILISATION SDL

Pour compiler, il faut rajouter à gcc les options suivantes:
-I/usr/include/SDL2 -D_REENTRANT -lSDL2

Exemple:

gcc test.c -o test -I/usr/include/SDL2 -D_REENTRANT -lSDL2
*/


#include <SDL.h>
#include <time.h>
#include <unistd.h>

#define H 480
#define W 640

SDL_Window* window; // fenêtre du programme
SDL_Renderer* renderer; // moteur de rendu

int main(){
	// Initialiser SDL: la fonction SDL_Init renvoie 0 si tout s'est bien passé
	if (SDL_Init(SDL_INIT_VIDEO) != 0){
		// SDL_GetError() renvoie un texte contenant la dernière erreur survenue
		printf("Erreur d'initialisation: %s\n", SDL_GetError());
		exit(1);
	}

	// Créer la fenêtre, au milieu de l'écran
	window = SDL_CreateWindow("Hello SDL", SDL_WINDOWPOS_CENTERED, SDL_WINDOWPOS_CENTERED, W, H, 0);
	if (window == NULL){
		printf("Erreur de création de la fenêtre: %s\n", SDL_GetError());
		exit(1);
	}

	// Initialiser le moteur de rendu et le lier à la fenêtre
	renderer = SDL_CreateRenderer(window, -1, SDL_RENDERER_ACCELERATED);
	if (renderer == NULL){
		printf("Erreur de création du renderer: %s\n", SDL_GetError());
		exit(1);
	}


	/*
	Le vrai code intéressant va ici, après toutes les initialisations.


	Fonctions utiles:
	SDL_RenderPresent(renderer) : met à jour la fenêtre avec les données
		de renderer. Si vous faites une animation, il faut l'appeler 
		après chaque image.

	SDL_RenderClear(renderer): efface tous les pixels enregistrés dans renderer.

	SDL_SetRenderDrawColor(renderer, r, g, b, 255): change la couleur actuelle
		du renderer en (r, g, b)
	SDL_RenderDrawPoint(renderer, x, y): fait dessiner au renderer un pixel en x, y
		N'affiche rien à l'écran tant que SDL_RenderPresent n'a pas été appelée	

	Voir fichiers test1, test2, test3 pour des démonstrations
	 */

	



	// Fin du programme: toujours appeler ces deux fonctions
	SDL_DestroyWindow(window);
	SDL_Quit();

	return 0;
}