#include <SDL.h>
#include <time.h>
#include <unistd.h>
#include <stdlib.h>

#define H 480
#define W 640

SDL_Window* window; 
SDL_Renderer* renderer; 

int main(){
	srand(time(NULL));
	if (SDL_Init(SDL_INIT_VIDEO) != 0){
		printf("Erreur d'initialisation: %s\n", SDL_GetError());
		exit(1);
	}
	window = SDL_CreateWindow("Hello SDL", SDL_WINDOWPOS_CENTERED, SDL_WINDOWPOS_CENTERED, W, H, 0);
	if (window == NULL){
		printf("Erreur de création de la fenêtre: %s\n", SDL_GetError());
		exit(1);
	}
	renderer = SDL_CreateRenderer(window, -1, SDL_RENDERER_ACCELERATED);
	if (renderer == NULL){
		printf("Erreur de création du renderer: %s\n", SDL_GetError());
		exit(1);
	}

	/* Exemple 2: petit carré qui se déplace dans l'espace.
		Le programme dessine 500 images, entre chaque image le carré
		se déplace un peu dans une direction aléatoire (une sorte de
		mouvement Brownien)

		Les images sont dessinées à un rythme de 50 images par seconde
	*/

	int x = H/2, y = W/2; // coordonnées initiales du point

	// chaque tour de boucle dessine et affiche une image
	for (int i = 0; i < 500; i++){
		// effacer l'écran
		SDL_SetRenderDrawColor(renderer, 0, 0, 0, 255); 
		SDL_RenderClear(renderer);
		// déplacer le carré
		x += (rand()%5-2);
		y += (rand()%5-2);

		// faire boucler le carré s'il sort de l'écran
		x = (x+W)%W;
		y = (y+H)%H;

		// afficher le point: carré de 5 pixels de côté
		SDL_SetRenderDrawColor(renderer, 235, 100, 100, 255); // couleur du point: rouge
		for (int j = 0; j < 5; ++j){
			for (int k = 0; k < 5; ++k){
				SDL_RenderDrawPoint(renderer, x+k, y+j);
			}
		}


		// mettre à jour la fenêtre
		SDL_RenderPresent(renderer);

		// pause de 20000 microsecondes
		// soit 1000000/20000 = 50 images par seconde
		usleep(20000);
	}


	SDL_DestroyWindow(window);
	SDL_Quit();

	return 0;
}